// $Id: NullSoundDriver.cc 5924 2006-12-14 20:50:54Z m9710797 $

#include "NullSoundDriver.hh"

namespace openmsx {

void NullSoundDriver::mute()
{
}

void NullSoundDriver::unmute()
{
}

unsigned NullSoundDriver::getFrequency() const
{
	return 44100;
}

unsigned NullSoundDriver::getSamples() const
{
	return 0;
}

double NullSoundDriver::uploadBuffer(short* /*buffer*/, unsigned /*len*/)
{
	return 1.0;
}

} // namespace openmsx
